
# Slot: version


particular version of schema

URI: [meta:version](https://w3id.org/biolink/biolinkml/meta/version)

## Domain and Range

[SchemaDefinition](SchemaDefinition.md) ->  <sub>OPT</sub> [String](String.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
